pub trait Modifier {
// Required method
fn process(&mut self, x: SampleT) -> SampleT;
}Expand description
The Modifier trait defines types that filter audio samples.
pub trait Modifier {
// Required method
fn process(&mut self, x: SampleT) -> SampleT;
}The Modifier trait defines types that filter audio samples.