Mono

Struct Mono 

pub struct Mono {
    pub mono: SampleT,
}
Struct representing a monophonic audio sample.

Fields

mono: SampleT

The single, monophonic sample.

Implementations

Source

impl Mono

pub fn new() -> Self

Creates a new Mono object with a default value of 0.

pub fn from(s: SampleT) -> Self

Creates a new Mono object from the given sample value.