bae_rs::sounds::complex_sound

Struct ComplexSound

pub struct ComplexSound { /* private fields */ }
Type implementing the ability to run multiple Generators and Modifiers within a single object, granting the ability to create complex systems like those found in digital synthesizers.

Implementations

Source

impl ComplexSound

pub fn new(input_gain: MathT, output_gain: MathT) -> Self

Creates a new ComplexSound object with the given input and output gain values.

pub fn get_input_gain(&self) -> GraphNode

Returns the [‘GraphNode’] containing the input gain Modifier.

pub fn get_output_gain(&self) -> GraphNode

Returns the [‘GraphNode’] containing the output gain Modifier.

pub fn add_block(&mut self, block: BlockSP) -> GraphNode

Adds a new node to the Graph, using the given Block for the node value. Returns the GraphNode containing the Block for later use with [add_connection] and [remove_connection].

pub fn add_connection(&mut self, from: GraphNode, to: GraphNode)

Adds a new connection (edge) between the two given GraphNodes.

pub fn remove_connection(&mut self, from: GraphNode, to: GraphNode)

Removes a connection between the two given GraphNodes.

pub fn get_nodes(&self) -> ProcessOrder

Returns a copy of the list of all nodes of the graph in the order in which they will be processed.