bae_rs::sounds::simple_sound

Struct SimpleSound

pub struct SimpleSound { /* private fields */ }
Struct implementing the ability to run a single Generator through a given list of Modifiers operated in series. This allows for simple and fast processing of the structure’s elements while still allowing for a wide range of more complex sounds.

Implementations

Source

impl SimpleSound

pub fn new(input_gain: MathT, output_gain: MathT, generator: BlockSP) -> Self

Constructs a new SimpleSound object. The new object is initialized with an empty Vec of Modifiers. Add Modifiers with add_modifier or extend_modifiers.

pub fn add_modifier<M>(&mut self, m: BlockSP)
where M: 'static + Clone,

Adds a single modifier to the internal Vec of Modifiers.

pub fn extend_modifiers(&mut self, m_list: Vec<BlockSP>)

Extends the internal Vec of Modifiers with the given Vec.

pub fn get_input_gain(&self) -> MathT

Returns the linear gain applied to the input during processing.

pub fn get_output_gain(&self) -> MathT

Returns the linear gain applied to the output during processing.

pub fn set_input_gain(&mut self, g: MathT)

Sets the input linear gain that is applied during processing.

pub fn set_output_gain(&mut self, g: MathT)

Sets the output linear gain that is applied during processing.