pub struct ComplexSound { /* private fields */ }Expand description
Implementations
Sourceimpl ComplexSound
impl ComplexSound
Sourcepub fn new(input_gain: MathT, output_gain: MathT) -> Self
pub fn new(input_gain: MathT, output_gain: MathT) -> Self
Creates a new ComplexSound object with the given input and output gain
values.
Sourcepub fn get_input_gain(&self) -> GraphNode
pub fn get_input_gain(&self) -> GraphNode
Returns the [‘GraphNode’] containing the input gain Modifier.
Sourcepub fn get_output_gain(&self) -> GraphNode
pub fn get_output_gain(&self) -> GraphNode
Returns the [‘GraphNode’] containing the output gain Modifier.
Sourcepub fn add_connection(&mut self, from: GraphNode, to: GraphNode)
pub fn add_connection(&mut self, from: GraphNode, to: GraphNode)
Adds a new connection (edge) between the two given GraphNodes.
Sourcepub fn remove_connection(&mut self, from: GraphNode, to: GraphNode)
pub fn remove_connection(&mut self, from: GraphNode, to: GraphNode)
Removes a connection between the two given GraphNodes.
Sourcepub fn get_nodes(&self) -> ProcessOrder
pub fn get_nodes(&self) -> ProcessOrder
Returns a copy of the list of all nodes of the graph in the order in which they will be processed.