pub struct SimpleSound { /* private fields */ }Expand description
Implementations
Sourceimpl SimpleSound
impl SimpleSound
Sourcepub fn new(input_gain: MathT, output_gain: MathT, generator: BlockSP) -> Self
pub fn new(input_gain: MathT, output_gain: MathT, generator: BlockSP) -> Self
Constructs a new SimpleSound object. The new object is initialized
with an empty Vec of Modifiers. Add Modifiers with
add_modifier or extend_modifiers.
Sourcepub fn add_modifier<M>(&mut self, m: BlockSP)where
M: 'static + Clone,
pub fn add_modifier<M>(&mut self, m: BlockSP)where
M: 'static + Clone,
Sourcepub fn extend_modifiers(&mut self, m_list: Vec<BlockSP>)
pub fn extend_modifiers(&mut self, m_list: Vec<BlockSP>)
Sourcepub fn get_input_gain(&self) -> MathT
pub fn get_input_gain(&self) -> MathT
Returns the linear gain applied to the input during processing.
Sourcepub fn get_output_gain(&self) -> MathT
pub fn get_output_gain(&self) -> MathT
Returns the linear gain applied to the output during processing.
Sourcepub fn set_input_gain(&mut self, g: MathT)
pub fn set_input_gain(&mut self, g: MathT)
Sets the input linear gain that is applied during processing.
Sourcepub fn set_output_gain(&mut self, g: MathT)
pub fn set_output_gain(&mut self, g: MathT)
Sets the output linear gain that is applied during processing.